==> http-client-executor-223.8214.52.jar: com/intellij/httpClient/http/request/run/preScript/js-rhino-pre-script-handler.js <==
function HttpClient(logPrinter, global) {
  this.global = new Variables(global);

  this.log = function (text) {
    logPrinter.accept(text + "\n")
  }
}

function Variables(existingVariables) {
  this.vars = {}

  for (var key in existingVariables) {
    this.vars[existingVariables[key].getKey()] = existingVariables[key].getValue()
  }

  this.set = function (varName, varValue) {
    this.vars[varName] = varValue
  }

  this.get = function (varName) {
    return this.vars[varName]
  }

  this.isEmpty = function () {
    return Object.keys(this.vars).length === 0
  }

  this.clear = function (varName) {
    delete this.vars[varName]
  }

  this.clearAll = function () {
    this.vars = {}
  }
}

function Body(elementsProvider) {
  this.__raw = elementsProvider.getRawBody()
  this.__substituted = elementsProvider.getSubstitutedBody()

  this.getRaw = function () {
    return this.__raw.getValue()
  }

  this.tryGetSubstituted = function () {
    return this.__substituted.getValue()
  }
}

function Environment(elementsProvider) {
  this.__env = elementsProvider;

  this.get = function (name) {
    return this.__env.getEnvironmentVariable(name);
  }
}

function Header(header) {
  this.name = header.name
  this.__raw = header.getRawValue()
  this.__substituted = header.getSubstitutedValue()

  this.getRawValue = function () {
    return this.__raw.getValue()
  }

  this.tryGetSubstitutedValue = function () {
    return this.__substituted.getValue()
  }
}

function Headers(provider) {
  this.__headers = provider.getHeaders()

  this.all = function () {
    const iterator = this.__headers.getValue().iterator()
    const result = []
    while (iterator.hasNext()) {
      let h = iterator.next()
      result.push(new Header(h))
    }
    return result
  }

  this.findByName = function (name) {
    const result = this.__headers.getValue().getHeader(name)
    return result !== null ? new Header(result) : null
  }
}

function Url(elementsProvider) {
  this.__raw = elementsProvider.getRawUrl()
  this.__substituted = elementsProvider.getSubstitutedUrl()

  this.getRaw = function () {
    return this.__raw.getValue()
  }

  this.tryGetSubstituted = function () {
    return this.__substituted.getValue()
  }
}

function Digest(delegate) {
  this.toBase64 = function (urlSafe) {
    return delegate.toBase64(!!(urlSafe || false))
  }

  this.toHex = function () {
    return delegate.toHex()
  }
}

function DigestBuilder(delegate) {
  this.updateWithText = function (message, encoding) {
    delegate.updateWithText(message, encoding || null)
    return this
  }

  this.updateWithHex = function (hex) {
    delegate.updateWithHex(hex)
    return this
  }

  this.updateWithBase64 = function (base64Text, urlSafe) {
    delegate.updateWithBase64(base64Text, !!(urlSafe || false))
    return this
  }

  this.digest = function () {
    return new Digest(delegate.digest())
  }
}

function HmacSupport(delegate) {
  this.sha1 = function () {
    return new HmacInitializer(delegate.sha1())
  }

  this.sha256 = function () {
    return new HmacInitializer(delegate.sha256())
  }

  this.sha512 = function () {
    return new HmacInitializer(delegate.sha512())
  }

  this.md5 = function () {
    return new HmacInitializer(delegate.md5())
  }
}

function HmacInitializer(delegate) {
  this.withTextSecret = function (secret, encoding) {
    return new DigestBuilder(delegate.withTextSecret(secret, encoding || null))
  }

  this.withHexSecret = function (hex) {
    return new DigestBuilder(delegate.withHexSecret(hex))
  }

  this.withBase64Secret = function (base64Secret, urlSafe) {
    return new DigestBuilder(delegate.withBase64Secret(base64Secret, !!(urlSafe || false)))
  }
}

function Crypto(delegate) {
  this.hmac = new HmacSupport(delegate.hmacSupport())

  this.sha1 = function () {
    return new DigestBuilder(delegate.sha1())
  }

  this.sha256 = function () {
    return new DigestBuilder(delegate.sha256())
  }

  this.sha512 = function () {
    return new DigestBuilder(delegate.sha512())
  }

  this.md5 = function () {
    return new DigestBuilder(delegate.md5())
  }
}

const jsHandler = function (
  logPrinter,
  elementsProvider,
  cryptoSupport,
  global
) {
  const client = new HttpClient(logPrinter, global)
  const request = {
    variables: new Variables([]),
    body: new Body(elementsProvider),
    url: new Url(elementsProvider),
    headers: new Headers(elementsProvider),
    environment: new Environment(elementsProvider),
  }
  const crypto = new Crypto(cryptoSupport)

  //<CUSTOM_SCRIPT_PLACEHOLDER>

  return {
    "request": request,
    "client": client
  }
}

==> http-client-executor-231.8109.175.jar: com/intellij/httpClient/http/request/run/preScript/js-rhino-pre-script-handler.js <==
function HttpClient(logPrinter, global) {
  this.global = new Variables(global);

  this.log = function (text) {
    logPrinter.accept(text + "\n")
  }
}

function __null_aware_to_string(value) {
  return value != null ? "" + value : value
}

function Variables(existingVariables) {
  this.vars = {}

  for (var key in existingVariables) {
    this.vars[existingVariables[key].getKey()] = __null_aware_to_string(existingVariables[key].getValue())
  }

  this.set = function (varName, varValue) {
    this.vars[varName] = varValue
  }

  this.get = function (varName) {
    return this.vars[varName]
  }

  this.isEmpty = function () {
    return Object.keys(this.vars).length === 0
  }

  this.clear = function (varName) {
    delete this.vars[varName]
  }

  this.clearAll = function () {
    this.vars = {}
  }
}

function Body(elementsProvider) {
  this.__raw = elementsProvider.getRawBody()
  this.__substituted = elementsProvider.getSubstitutedBody()

  this.getRaw = function () {
    return __null_aware_to_string(this.__raw.getValue())
  }

  this.tryGetSubstituted = function () {
    return __null_aware_to_string(this.__substituted.getValue())
  }
}

function Environment(elementsProvider) {
  this.__env = elementsProvider;

  this.get = function (name) {
    return __null_aware_to_string(this.__env.getEnvironmentVariable(name));
  }
}

function Header(header) {
  this.name = __null_aware_to_string(header.name)
  this.__raw = header.getRawValue()
  this.__substituted = header.getSubstitutedValue()

  this.getRawValue = function () {
    return __null_aware_to_string(this.__raw.getValue())
  }

  this.tryGetSubstitutedValue = function () {
    return __null_aware_to_string(this.__substituted.getValue())
  }
}

function Headers(provider) {
  this.__headers = provider.getHeaders()

  this.all = function () {
    const iterator = this.__headers.getValue().iterator()
    const result = []
    while (iterator.hasNext()) {
      let h = iterator.next()
      result.push(new Header(h))
    }
    return result
  }

  this.findByName = function (name) {
    const result = this.__headers.getValue().getHeader(name)
    return result !== null ? new Header(result) : null
  }
}

function Url(elementsProvider) {
  this.__raw = elementsProvider.getRawUrl()
  this.__substituted = elementsProvider.getSubstitutedUrl()

  this.getRaw = function () {
    return __null_aware_to_string(this.__raw.getValue())
  }

  this.tryGetSubstituted = function () {
    return __null_aware_to_string(this.__substituted.getValue())
  }
}

function Digest(delegate) {
  this.toBase64 = function (urlSafe) {
    return __null_aware_to_string(delegate.toBase64(!!(urlSafe || false)))
  }

  this.toHex = function () {
    return __null_aware_to_string(delegate.toHex())
  }
}

function DigestBuilder(delegate) {
  this.updateWithText = function (message, encoding) {
    delegate.updateWithText(message, encoding || null)
    return this
  }

  this.updateWithHex = function (hex) {
    delegate.updateWithHex(hex)
    return this
  }

  this.updateWithBase64 = function (base64Text, urlSafe) {
    delegate.updateWithBase64(base64Text, !!(urlSafe || false))
    return this
  }

  this.digest = function () {
    return new Digest(delegate.digest())
  }
}

function HmacSupport(delegate) {
  this.sha1 = function () {
    return new HmacInitializer(delegate.sha1())
  }

  this.sha256 = function () {
    return new HmacInitializer(delegate.sha256())
  }

  this.sha512 = function () {
    return new HmacInitializer(delegate.sha512())
  }

  this.md5 = function () {
    return new HmacInitializer(delegate.md5())
  }
}

function HmacInitializer(delegate) {
  this.withTextSecret = function (secret, encoding) {
    return new DigestBuilder(delegate.withTextSecret(secret, encoding || null))
  }

  this.withHexSecret = function (hex) {
    return new DigestBuilder(delegate.withHexSecret(hex))
  }

  this.withBase64Secret = function (base64Secret, urlSafe) {
    return new DigestBuilder(delegate.withBase64Secret(base64Secret, !!(urlSafe || false)))
  }
}

function Crypto(delegate) {
  this.hmac = new HmacSupport(delegate.hmacSupport())

  this.sha1 = function () {
    return new DigestBuilder(delegate.sha1())
  }

  this.sha256 = function () {
    return new DigestBuilder(delegate.sha256())
  }

  this.sha512 = function () {
    return new DigestBuilder(delegate.sha512())
  }

  this.md5 = function () {
    return new DigestBuilder(delegate.md5())
  }
}

const jsHandler = function (
  logPrinter,
  elementsProvider,
  cryptoSupport,
  global
) {
  const client = new HttpClient(logPrinter, global)
  const request = {
    variables: new Variables([]),
    body: new Body(elementsProvider),
    url: new Url(elementsProvider),
    headers: new Headers(elementsProvider),
    environment: new Environment(elementsProvider),
  }
  const crypto = new Crypto(cryptoSupport)

  //<CUSTOM_SCRIPT_PLACEHOLDER>

  return {
    "request": request,
    "client": client
  }
}
